pygeodesy.lcc

Package pygeodesy :: Module lcc |
[frames] | no frames]

# Module lcc

Lambert Conformal Conic (LCC) projection.

Lambert conformal conic projection for 1- or 2-Standard Parallels classes Conic, Conics registry, LCCError and position class Lcc.

See LCC, Lambert Conformal Conic to Geographic Transformation Formulae, Lambert Conformal Conic Projection and John P. Snyder 'Map Projections - A Working Manual', 1987, pp 107-109.

Version: 25.08.31

Classes
| Conic Lambert conformal conic projection (1- or 2-SP).
| LCCError Lambert Conformal Conic `LCC` or other Lcc issue.
| Lcc Lambert conformal conic East-/Northing location.

Functions
toLcc(latlon, conic=Conic(name='WRF_Lb', lat0=40, lon0=-97, par1=33, par2=45, E0=0`...`, height=None, Lcc=<class 'pygeodesy.lcc.Lcc'>, **name_Lcc_kwds) Convert an (ellipsoidal) geodetic point to a Lambert location. |

Variables
| __all__ = `_ALL_LAZY.lcc`
| Conics = `Conics.WRF_Lb: Conic(name='WRF_Lb', lat0=40, lon0=-97`...`` Some pre-defined Conics, all lazily instantiated.
| Conics.Be08Lb Conic(name='Be08Lb', lat0=50.797815, lon0=4.35921583, par1=49.8333339, par2=51.1666672, E0=649328, N0=665262, k0=1, SP=2, datum=Datum(name='GRS80', ellipsoid=Ellipsoids.GRS80, transform=Transforms.WGS84),
| Conics.Be72Lb Conic(name='Be72Lb', lat0=90, lon0=4.3674867, par1=49.8333339, par2=51.1666672, E0=150000.013, N0=5400088.438, k0=1, SP=2, datum=Datum(name='NAD83', ellipsoid=Ellipsoids.GRS80, transform=Transforms.NAD83),
| Conics.Fr93Lb Conic(name='Fr93Lb', lat0=46.5, lon0=3, par1=49, par2=44, E0=700000, N0=6600000, k0=1, SP=2, datum=Datum(name='WGS84', ellipsoid=Ellipsoids.WGS84, transform=Transforms.WGS84),
| Conics.MaNLb Conic(name='MaNLb', lat0=33.3, lon0=-5.4, par1=31.73, par2=34.87, E0=500000, N0=300000, k0=1, SP=2, datum=Datum(name='NTF', ellipsoid=Ellipsoids.Clarke1880IGN, transform=Transforms.NTF),
| Conics.MxLb Conic(name='MxLb', lat0=12, lon0=-102, par1=17.5, par2=29.5, E0=2500000, N0=0, k0=1, SP=2, datum=Datum(name='WGS84', ellipsoid=Ellipsoids.WGS84, transform=Transforms.WGS84),
| Conics.PyT_Lb Conic(name='PyT_Lb', lat0=46.8, lon0=2.33722917, par1=45.8989389, par2=47.6960144, E0=600000, N0=200000, k0=1, SP=2, datum=Datum(name='NTF', ellipsoid=Ellipsoids.Clarke1880IGN, transform=Transforms.NTF),
| Conics.USA_Lb Conic(name='USA_Lb', lat0=23, lon0=-96, par1=33, par2=45, E0=0, N0=0, k0=1, SP=2, datum=Datum(name='WGS84', ellipsoid=Ellipsoids.WGS84, transform=Transforms.WGS84),
| Conics.WRF_Lb Conic(name='WRF_Lb', lat0=40, lon0=-97, par1=33, par2=45, E0=0, N0=0, k0=1, SP=2, datum=Datum(name='WGS84', ellipsoid=Ellipsoids.WGS84, transform=Transforms.WGS84)

Function Details

### toLcc (latlon, conic=Conic(name='WRF_Lb', lat0=40, lon0=-97, par1=33, par2=45, E0=0`...`, height=None, Lcc=<class 'pygeodesy.lcc.Lcc'>, **name_Lcc_kwds) |
Convert an (ellipsoidal) geodetic point to a Lambert location. Arguments: `latlon` - Ellipsoidal point (`LatLon`). `conic` - Optional Lambert projection to use (Conic). `height` - Optional height for the point, overriding the default height (`meter`). `Lcc` - Class to return the Lambert location (Lcc). `name_Lcc_kwds` - Optional `name=NN` (`str`) and optionally, additional `Lcc` keyword arguments, ignored if `Lcc` is None. Returns: The Lambert location (Lcc) or if `Lcc is None`, an EasNor3Tuple`(easting, northing, height)`. Raises: `TypeError` - If `latlon` is not ellipsoidal.

Variables Details

  ### Conics Some pre-defined Conics, all lazily instantiated. Value:
      Conics.WRF_Lb: Conic(name='WRF_Lb', lat0=40, lon0=-97, par1=33, par2=4
      5, E0=0, N0=0, k0=1, SP=2, datum=Datum(name='WGS84', ellipsoid=Ellipso
      ids.WGS84, transform=Transforms.WGS84))